Index: src/examples/test_chisq_panel.py
===================================================================
--- src/examples/test_chisq_panel.py	(revision f468791f8ac1d2498ad79b33a2c4a0f06236dec8)
+++ src/examples/test_chisq_panel.py	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -27,6 +27,6 @@
 
 import wx
-from sans.plottools.PlotPanel import PlotPanel
-from sans.plottools.plottables import Plottable, Graph, Data1D, Theory1D
+from sas.plottools.PlotPanel import PlotPanel
+from sas.plottools.plottables import Plottable, Graph, Data1D, Theory1D
 import  sys
 import numpy
@@ -86,5 +86,5 @@
         dy = numpy.sqrt(100*numpy.abs(y))/100
 
-    from sans.plottools.plottables import Data1D, Theory1D, Chisq , Graph
+    from sas.plottools.plottables import Data1D, Theory1D, Chisq , Graph
     data = Data1D(x,y,dy=dy)
     data.xaxis('distance', 'm')
Index: src/examples/test_copy_print.py
===================================================================
--- src/examples/test_copy_print.py	(revision f468791f8ac1d2498ad79b33a2c4a0f06236dec8)
+++ src/examples/test_copy_print.py	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -26,6 +26,6 @@
 
 import wx
-from sans.plottools.PlotPanel import PlotPanel
-from sans.plottools.plottables import Graph, Data1D, Theory1D
+from sas.plottools.PlotPanel import PlotPanel
+from sas.plottools.plottables import Graph, Data1D, Theory1D
 import  sys
 sys.platform = 'win95'
Index: src/examples/test_text_panel.py
===================================================================
--- src/examples/test_text_panel.py	(revision f468791f8ac1d2498ad79b33a2c4a0f06236dec8)
+++ src/examples/test_text_panel.py	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -27,6 +27,6 @@
 
 import wx
-from sans.plottools.PlotPanel import PlotPanel
-from sans.plottools.plottables import Text, Graph
+from sas.plottools.PlotPanel import PlotPanel
+from sas.plottools.plottables import Text, Graph
 
 class TestPlotPanel(PlotPanel):

Index: src/examples/test_panel.py
===================================================================
--- src/examples/test_panel.py	(revision f468791f8ac1d2498ad79b33a2c4a0f06236dec8)
+++ src/examples/test_panel.py	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -1,5 +1,5 @@
 """
     Test application that uses plottools
     This application uses most of the functionality required by the SANS group
     and should be treated as a test-case representative of that use.
     
@@ -37,6 +37,6 @@
 """
 import wx
-from sans.plottools.PlotPanel import PlotPanel
-from sans.plottools.plottables import Data1D
+from sas.plottools.PlotPanel import PlotPanel
+from sas.plottools.plottables import Data1D
 import  sys
 import numpy
@@ -44,5 +44,5 @@
 
 
-class SANSplotpanel(PlotPanel):
+class SASplotpanel(PlotPanel):
     
     def __init__(self, parent, id = -1, color = None,\
@@ -94,5 +94,5 @@
         
         # Panel for 1D plot
-        self.plotpanel    = SANSplotpanel(self, -1, style=wx.RAISED_BORDER)
+        self.plotpanel    = SASplotpanel(self, -1, style=wx.RAISED_BORDER)
 
         # Set up the menu
@@ -1,5 +1,5 @@
 """
     Test application that uses plottools
-    This application uses most of the functionality required by the SANS group
+    This application uses most of the functionality required by the SAS group
     and should be treated as a test-case representative of that use.
     
Index: src/examples/test_panel2D.py
===================================================================
--- src/examples/test_panel2D.py	(revision f468791f8ac1d2498ad79b33a2c4a0f06236dec8)
+++ src/examples/test_panel2D.py	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -1,5 +1,5 @@
 """
     Test application that uses plottools
     This application uses most of the functionality required by the SANS group
     and should be treated as a test-case representative of that use.
     
@@ -37,6 +37,6 @@
 """
 import wx
-from sans.plottools.PlotPanel import PlotPanel
-from sans.plottools.plottables import Data1D, Theory1D, Data2D
+from sas.plottools.PlotPanel import PlotPanel
+from sas.plottools.plottables import Data1D, Theory1D, Data2D
 import  sys,os
 import numpy
@@ -44,5 +44,5 @@
 
 
-class SANSplotpanel(PlotPanel):
+class SASplotpanel(PlotPanel):
     
     def __init__(self, parent, id = -1, color = None,\
@@ -136,5 +136,5 @@
         
         # Panel for 1D plot
-        self.plotpanel    = SANSplotpanel(self, -1, style=wx.RAISED_BORDER)
+        self.plotpanel    = SASplotpanel(self, -1, style=wx.RAISED_BORDER)
 
         # Set up the menu
@@ -200,5 +200,5 @@
             path = dlg.GetPath()
             mypath = os.path.basename(path)
-            from sans.dataloader.loader import  Loader
+            from sas.dataloader.loader import  Loader
            
             #Instantiate a loader 
@@ -1,5 +1,5 @@
 """
     Test application that uses plottools
-    This application uses most of the functionality required by the SANS group
+    This application uses most of the functionality required by the SAS group
     and should be treated as a test-case representative of that use.
     